#[repr(C)]pub enum RuntimeNamespace {
Global,
Local {
site: Option<NonZeroU32>,
},
Operation,
Type,
}Variants
Global
Used for things that participate in all namespaces. These are manifests, blocks, …
Local
Used for things that participate in no namespaces except the local definition. These are fields, enum variants, …
Fields

site: Option<NonZeroU32>Operation
Used for things that define operations or things you can do with a driver. These are registers, commands, buffers, …
Type
Used for things that define a type. These are devices, fieldsets, enums, …
Implementations
Sourceimpl RuntimeNamespace
impl RuntimeNamespace
pub fn concrete_namespaces(&self) -> Vec<RuntimeNamespace>