Identifier

Struct Identifier 

pub struct Identifier<T: IdentifierType> { /* private fields */ }
A structure that holds the name data of objects

Implementations

Source

impl<T: IdentifierType> Identifier<T>

pub fn try_parse(value: &str) -> Result<Self, Error>
where T: Default,

Try parse a string as an identifier. It will not have boundaries applied yet.

pub fn try_parse_with_type(value: &str, id_type: T) -> Result<Self, Error>

Try parse a string as an identifier. It will not have boundaries applied yet.

pub fn apply_boundaries(&mut self, boundaries: &[Boundary]) -> &mut Self

Apply the boundaries. This can only be called once and must be called before Self::to_case

pub fn check_validity(&self) -> Result<(), Error>

pub fn to_case(&self, case: Case<'_>) -> String

Convert the identifier to a string in the given case

pub fn original(&self) -> &str

Get the original text. Don’t use this unless it’s important to get the exact original value. Better to use Self::to_case in most circumstances.

pub fn words_display(&self) -> String

Get a display string that separates the words that make up the identifier visually

pub fn words_display_prepended(&self, word: String) -> String

Same as Self::words_display, but prepends another word

pub fn is_empty(&self) -> bool

pub fn take_ref(&self) -> IdentifierRef<T>
where T: Clone,

Get a type ref if this is a type identifier

pub fn set_duplicate_id(&mut self, val: NonZeroU32)

pub fn duplicate_id(&self) -> Option<NonZeroU32>

pub fn to_runtime_type(self) -> Identifier<RuntimeType>

pub fn as_runtime_type_mut(&mut self) -> &mut Identifier<RuntimeType>

pub fn as_runtime_type(&self) -> &Identifier<RuntimeType>

pub fn id_type(&self) -> &T

Get the identifier type

pub fn cast<U>(self) -> Identifier<U>
where U: IdentifierType + Default + From<T>,

Change the type of the identifier to a more specific type

pub fn cast_unchecked<U: IdentifierType + Default>(self) -> Identifier<U>

Change the type of the identifier. This is generally a bad idea because of the subtleties! So make sure this is actually what you want.

pub fn cast_assert<U: IdentifierType + Default>(self) -> Identifier<U>

Change the type of the identifier, but only if the runtime type is already that type. This function will panic if they’re different.