pub enum AddressMode {
Mapped,
Indexed,
}Expand description
Type to specify how addresses work
Variants
Mapped
Objects are memory-mapped.
If object A has address X and is Y bytes big, then object B (if it exists) will have the address X+Y.
Indexed
Objects are sequentially indexed.
If object A has address X, then object B (if it exists) will have the address X+1.