pub struct Identifier<T: IdentifierType> { /* private fields */ }Expand description
A structure that holds the name data of objects
Implementations
Sourceimpl<T: IdentifierType> Identifier<T>
impl<T: IdentifierType> Identifier<T>
Sourcepub fn try_parse(value: &str) -> Result<Self, Error>where
T: Default,
pub fn try_parse(value: &str) -> Result<Self, Error>where
T: Default,
Try parse a string as an identifier. It will not have boundaries applied yet.
Sourcepub fn try_parse_with_type(value: &str, id_type: T) -> Result<Self, Error>
pub fn try_parse_with_type(value: &str, id_type: T) -> Result<Self, Error>
Try parse a string as an identifier. It will not have boundaries applied yet.
Sourcepub fn apply_boundaries(&mut self, boundaries: &[Boundary]) -> &mut Self
pub fn apply_boundaries(&mut self, boundaries: &[Boundary]) -> &mut Self
Apply the boundaries. This can only be called once and must be called before Self::to_case
pub fn check_validity(&self) -> Result<(), Error>
Sourcepub fn to_case(&self, case: Case<'_>) -> String
pub fn to_case(&self, case: Case<'_>) -> String
Convert the identifier to a string in the given case
Sourcepub fn original(&self) -> &str
pub fn original(&self) -> &str
Get the original text. Don’t use this unless it’s important to get the exact original value.
Better to use Self::to_case in most circumstances.
Sourcepub fn words_display(&self) -> String
pub fn words_display(&self) -> String
Get a display string that separates the words that make up the identifier visually
Sourcepub fn words_display_prepended(&self, word: String) -> String
pub fn words_display_prepended(&self, word: String) -> String
Same as Self::words_display, but prepends another word
pub fn is_empty(&self) -> bool
Sourcepub fn take_ref(&self) -> IdentifierRef<T>where
T: Clone,
pub fn take_ref(&self) -> IdentifierRef<T>where
T: Clone,
Get a type ref if this is a type identifier
pub fn set_duplicate_id(&mut self, val: NonZeroU32)
pub fn duplicate_id(&self) -> Option<NonZeroU32>
pub fn to_runtime_type(self) -> Identifier<RuntimeType>
pub fn as_runtime_type_mut(&mut self) -> &mut Identifier<RuntimeType>
pub fn as_runtime_type(&self) -> &Identifier<RuntimeType>
Sourcepub fn cast<U>(self) -> Identifier<U>
pub fn cast<U>(self) -> Identifier<U>
Change the type of the identifier to a more specific type
Sourcepub fn cast_unchecked<U: IdentifierType + Default>(self) -> Identifier<U>
pub fn cast_unchecked<U: IdentifierType + Default>(self) -> Identifier<U>
Change the type of the identifier. This is generally a bad idea because of the subtleties! So make sure this is actually what you want.
Sourcepub fn cast_assert<U: IdentifierType + Default>(self) -> Identifier<U>
pub fn cast_assert<U: IdentifierType + Default>(self) -> Identifier<U>
Change the type of the identifier, but only if the runtime type is already that type. This function will panic if they’re different.