pub struct Span {
pub start: usize,
pub end: usize,
}Fields
start: usizeend: usizeImplementations
Sourceimpl Span
impl Span
pub const fn empty() -> Self
pub fn is_empty(&self) -> bool
Sourcepub fn or(&self, other: Self) -> Self
pub fn or(&self, other: Self) -> Self
Return self if not empty, or the other span if self is empty
Sourcepub fn to(&self, other: Self) -> Self
pub fn to(&self, other: Self) -> Self
Get the combined span that encompasses both spans. The order does not matter.
Sourcepub fn skip(&self, skip: Self) -> Self
pub fn skip(&self, skip: Self) -> Self
Take the current span, but skip the start until the skip span has been passed
Sourcepub fn start_from(&self, start: Self) -> Self
pub fn start_from(&self, start: Self) -> Self
Take the current span, but skip the first part and start from the given start span
Sourcepub fn collapse_to_end(&self) -> Span
pub fn collapse_to_end(&self) -> Span
Discard the span and keep a zero-length span at the end value