pub enum Integer {
U8,
U16,
U32,
U64,
I8,
I16,
I32,
I64,
}Variants
Implementations
Sourceimpl Integer
impl Integer
pub const fn is_signed(&self) -> bool
pub const fn min_value(&self) -> i128
pub const fn max_value(&self) -> i128
pub const fn size_bits(&self) -> u32
Sourcepub const fn find_smallest(
min: i128,
max: i128,
size_bits: u64,
) -> Option<Integer>
pub const fn find_smallest( min: i128, max: i128, size_bits: u64, ) -> Option<Integer>
Find the smallest integer type that can fully contain the min and max
and is equal or larger than the given size_bits.
This function has a preference for unsigned integers. You can force a signed integer by making the min be negative (e.g. -1)
Sourcepub const fn bits_required(&self, min: i128, max: i128) -> u32
pub const fn bits_required(&self, min: i128, max: i128) -> u32
Given the min and the max and the sign of the integer, how many bits are required to fit the min and max? (inclusive)